@@ -113,8 +113,8 @@ ImapResource::ImapResource( const QString &id )
   m_pool->setPasswordRequester( new SettingsPasswordRequester( this, m_pool ) );
   m_pool->setSessionUiProxy( SessionUiProxy::Ptr( new SessionUiProxy ) );
 
-  connect( m_pool, SIGNAL(connectDone(int, QString)),
-           this, SLOT(onConnectDone(int, QString)) );
+  connect( m_pool, SIGNAL(connectDone(int,QString)),
+           this, SLOT(onConnectDone(int,QString)) );
   connect( m_pool, SIGNAL(connectionLost(KIMAP::Session*)),
            this, SLOT(onConnectionLost(KIMAP::Session*)) );
 
@@ -135,6 +135,7 @@ ImapResource::ImapResource( const QString &id )
   changeRecorder()->itemFetchScope().fetchFullPayload( true );
   changeRecorder()->itemFetchScope().setAncestorRetrieval( ItemFetchScope::All );
   changeRecorder()->itemFetchScope().setFetchModificationTime( false );
+ //(Andras) disable now, as tokoe reported problems with it and the mail filter: changeRecorder()->fetchChangedOnly( true );
 
   setHierarchicalRemoteIdentifiersEnabled( true );
   setItemTransactionMode( ItemSync::MultipleTransactions ); // we can recover from incomplete syncs, so we can use a faster mode
@@ -238,6 +239,11 @@ void ImapResource::onConnectDone( int errorCode, const QString &errorString )
     taskDone();
     return;
 
+  case SessionPool::CouldNotConnectError:
+    setOnline( false );
+    taskDone();
+    return;
+
   case SessionPool::ReconnectNeededError:
     reconnect();
     return;
