@@ -91,8 +91,8 @@ void RetrieveCollectionsTask::doStart( KIMAP::Session *session )
   KIMAP::ListJob *listJob = new KIMAP::ListJob( session );
   listJob->setIncludeUnsubscribed( !isSubscriptionEnabled() );
   listJob->setQueriedNamespaces( serverNamespaces() );
-  connect( listJob, SIGNAL( mailBoxesReceived(QList<KIMAP::MailBoxDescriptor>, QList< QList<QByteArray> >) ),
-           this, SLOT( onMailBoxesReceived(QList<KIMAP::MailBoxDescriptor>, QList< QList<QByteArray> >) ) );
+  connect( listJob, SIGNAL(mailBoxesReceived(QList<KIMAP::MailBoxDescriptor>,QList<QList<QByteArray> >)),
+           this, SLOT(onMailBoxesReceived(QList<KIMAP::MailBoxDescriptor>,QList<QList<QByteArray> >)) );
   connect( listJob, SIGNAL(result(KJob*)), SLOT(onMailBoxesReceiveDone(KJob*)) );
   listJob->start();
 }
@@ -199,8 +199,9 @@ void RetrieveCollectionsTask::onFullMailBoxesReceived( const QList< KIMAP::MailB
                                                        const QList< QList< QByteArray > >& flags )
 {
   Q_UNUSED( flags );
-  foreach ( const KIMAP::MailBoxDescriptor &descriptor, descriptors )
+  foreach ( const KIMAP::MailBoxDescriptor &descriptor, descriptors ) {
     m_fullReportedCollections.insert( descriptor.name );
+  }
 }
 
 void RetrieveCollectionsTask::onFullMailBoxesReceiveDone(KJob* job)
@@ -210,7 +211,6 @@ void RetrieveCollectionsTask::onFullMailBoxesReceiveDone(KJob* job)
   }
 }
 
-
 #include "retrievecollectionstask.moc"
 
 
