@@ -30,8 +30,6 @@
 #include <kimap/capabilitiesjob.h>
 #include <kimap/logoutjob.h>
 #include <kimap/namespacejob.h>
-#include <kimap/session.h>
-#include <kimap/sessionuiproxy.h>
 
 #include <kpimutils/networkaccesshelper.h>
 
@@ -40,7 +38,7 @@
 
 qint64 SessionPool::m_requestCounter = 0;
 
-SessionPool::SessionPool( int maxPoolSize, QObject *parent)
+SessionPool::SessionPool( int maxPoolSize, QObject *parent )
   : QObject( parent ),
     m_maxPoolSize( maxPoolSize ),
     m_account( 0 ),
@@ -67,8 +65,8 @@ void SessionPool::setPasswordRequester( PasswordRequesterInterface *requester )
 
   m_passwordRequester = requester;
   m_passwordRequester->setParent( this );
-  QObject::connect( m_passwordRequester, SIGNAL(done(int, QString)),
-                    this, SLOT(onPasswordRequestDone(int, QString)) );
+  QObject::connect( m_passwordRequester, SIGNAL(done(int,QString)),
+                    this, SLOT(onPasswordRequestDone(int,QString)) );
 }
 
 KIMAP::SessionUiProxy::Ptr SessionPool::sessionUiProxy() const
@@ -115,10 +113,10 @@ void SessionPool::disconnect( SessionTermination termination )
 
   m_networkAccessHelper->releaseConnection();
 
-  foreach ( KIMAP::Session *s, m_idlePool+m_reservedPool ) {
+  foreach ( KIMAP::Session *s, m_unusedPool + m_reservedPool ) {
     killSession( s, termination );
   }
-  m_idlePool.clear();
+  m_unusedPool.clear();
   m_reservedPool.clear();
 
   delete m_account;
@@ -152,7 +150,7 @@ void SessionPool::releaseSession( KIMAP::Session *session )
 {
   if ( !m_reservedPool.isEmpty() && m_reservedPool.contains( session ) ) {
     m_reservedPool.removeAll( session );
-    m_idlePool << session;
+    m_unusedPool << session;
   }
 }
 
@@ -173,15 +171,15 @@ QList<KIMAP::MailBoxDescriptor> SessionPool::serverNamespaces() const
 
 void SessionPool::killSession( KIMAP::Session *session, SessionTermination termination )
 {
-  QObject::disconnect( session, SIGNAL(connectionLost()),
-                       this, SLOT(onEarlyConnectionLost()) );
-  QObject::disconnect( session, SIGNAL(connectionLost()),
-                       this, SLOT(onConnectionLost()) );
+  QObject::disconnect( session, SIGNAL(stateChanged(KIMAP::Session::State,KIMAP::Session::State)),
+                       this, SLOT(onSessionStateChanged(KIMAP::Session::State,KIMAP::Session::State)) );
+  m_unusedPool.removeAll( session );
+  m_reservedPool.removeAll( session );
 
   if ( session->state() != KIMAP::Session::Disconnected && termination == LogoutSession ) {
     KIMAP::LogoutJob *logout = new KIMAP::LogoutJob( session );
-    QObject::connect( logout, SIGNAL( result( KJob* ) ),
-                      session, SLOT( deleteLater() ) );
+    QObject::connect( logout, SIGNAL(result(KJob*)),
+                      session, SLOT(deleteLater()) );
     logout->start();
   } else {
     session->close();
@@ -193,13 +191,8 @@ void SessionPool::declareSessionReady( KIMAP::Session *session )
 {
   m_pendingInitialSession = 0;
 
-  QObject::disconnect( session, SIGNAL(connectionLost()),
-                       this, SLOT(onEarlyConnectionLost()) );
-  QObject::connect( session, SIGNAL(connectionLost()),
-                    this, SLOT(onConnectionLost()) );
-
   if ( !m_initialConnectDone ) {
-    m_idlePool << session;
+    m_unusedPool << session;
     m_initialConnectDone = true;
     emit connectDone();
   } else {
@@ -213,15 +206,23 @@ void SessionPool::declareSessionReady( KIMAP::Session *session )
   }
 }
 
-void SessionPool::cancelSessionCreation( KIMAP::Session *session, int errorCode, const QString &errorMessage )
+void SessionPool::cancelSessionCreation( KIMAP::Session *session, int errorCode,
+                                         const QString &errorMessage )
 {
   m_pendingInitialSession = 0;
 
+  if ( m_account ) {
+    emit connectDone( errorCode,
+                      i18n( "Could not connect to the IMAP-server %1.\n%2",
+                            m_account->server(), errorMessage ) );
+  } else {
+    // Can happen when we lose all ready connections while trying to establish
+    // a new connection, for example.
+    emit connectDone( errorCode,
+                      i18n( "Cound not connect to the IMAP server.\n%1", errorMessage ) );
+  }
+
   if ( !m_initialConnectDone ) {
-    if ( m_account )
-      emit connectDone( errorCode, i18n( "Could not connect to the IMAP-server %1.\n%2", m_account->server(), errorMessage ) );
-    else // this case can happen when we loose all ready connections while trying to establish a new one for example
-      emit connectDone( errorCode, i18n( "Cound not connect to the IMAP server.\n%1", errorMessage ) );
     disconnect();
     killSession( session, LogoutSession );
   } else {
@@ -237,9 +238,9 @@ void SessionPool::cancelSessionCreation( KIMAP::Session *session, int errorCode,
 
 void SessionPool::processPendingRequests()
 {
-  if ( !m_idlePool.isEmpty() ) {
+  if ( !m_unusedPool.isEmpty() ) {
     // We have a session ready to give out
-    KIMAP::Session *session = m_idlePool.takeFirst();
+    KIMAP::Session *session = m_unusedPool.takeFirst();
     m_reservedPool << session;
     if ( !m_pendingRequests.isEmpty() ) {
       emit sessionRequestDone( m_pendingRequests.takeFirst(), session );
@@ -247,7 +248,7 @@ void SessionPool::processPendingRequests()
         QTimer::singleShot( 0, this, SLOT(processPendingRequests()) );
       }
     }
-  } else if ( m_idlePool.size() + m_reservedPool.size() < m_maxPoolSize ) {
+  } else if ( m_unusedPool.size() + m_reservedPool.size() < m_maxPoolSize ) {
     // We didn't reach the max pool size yet so create a new one
     m_passwordRequester->requestPassword();
 
@@ -265,7 +266,7 @@ void SessionPool::processPendingRequests()
   }
 }
 
-void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
+void SessionPool::onPasswordRequestDone( int resultType, const QString &password )
 {
   QString errorMessage;
 
@@ -279,13 +280,12 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
     return;
   }
 
-  switch ( resultType )
-  {
+  switch ( resultType ) {
   case PasswordRequesterInterface::PasswordRetrieved:
     // All is fine
     break;
   case PasswordRequesterInterface::ReconnectNeeded:
-    Q_ASSERT( m_pendingInitialSession!=0 );
+    Q_ASSERT( m_pendingInitialSession != 0 );
     cancelSessionCreation( m_pendingInitialSession, ReconnectNeededError, errorMessage );
     return;
   case PasswordRequesterInterface::UserRejected:
@@ -306,12 +306,11 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
     return;
   }
 
-
   if ( m_account->encryptionMode() != KIMAP::LoginJob::Unencrypted && !QSslSocket::supportsSsl() ) {
     kWarning() << "Crypto not supported!";
     emit connectDone( EncryptionError,
-                i18n( "You requested TLS/SSL to connect to %1, but your "
-                      "system does not seem to be set up for that.", m_account->server() ) );
+                      i18n( "You requested TLS/SSL to connect to %1, but your "
+                            "system does not seem to be set up for that.", m_account->server() ) );
     disconnect();
     return;
   }
@@ -324,7 +323,9 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
     session->setUiProxy( m_sessionUiProxy );
     session->setTimeout( m_account->timeout() );
   }
-  QObject::connect( session, SIGNAL(connectionLost()), this, SLOT(onEarlyConnectionLost()) );
+
+  QObject::connect( session, SIGNAL(stateChanged(KIMAP::Session::State,KIMAP::Session::State)),
+                    this, SLOT(onSessionStateChanged(KIMAP::Session::State,KIMAP::Session::State)) );
 
   KIMAP::LoginJob *loginJob = new KIMAP::LoginJob( session );
   loginJob->setUserName( m_account->userName() );
@@ -332,43 +333,43 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
   loginJob->setEncryptionMode( m_account->encryptionMode() );
   loginJob->setAuthenticationMode( m_account->authenticationMode() );
 
-  QObject::connect( loginJob, SIGNAL( result( KJob* ) ),
-                    this, SLOT( onLoginDone( KJob* ) ) );
+  QObject::connect( loginJob, SIGNAL(result(KJob*)),
+                    this, SLOT(onLoginDone(KJob*)) );
   loginJob->start();
 }
 
-void SessionPool::onEarlyConnectionLost()
-{
-  kDebug() << sender();
-  KIMAP::Session *session = qobject_cast<KIMAP::Session*>( sender() );
-  Q_ASSERT( session );
-  cancelSessionCreation( session, LoginFailError, i18n( "Failed to connect to server" ) );
-}
-
 void SessionPool::onLoginDone( KJob *job )
 {
   KIMAP::LoginJob *login = static_cast<KIMAP::LoginJob*>( job );
 
-  if ( job->error()==0 ) {
+  if ( job->error() == 0 ) {
     if ( m_initialConnectDone ) {
       declareSessionReady( login->session() );
     } else {
       // On initial connection we ask for capabilities
       KIMAP::CapabilitiesJob *capJob = new KIMAP::CapabilitiesJob( login->session() );
-      QObject::connect( capJob, SIGNAL( result( KJob* ) ), SLOT( onCapabilitiesTestDone( KJob* ) ) );
+      QObject::connect( capJob, SIGNAL(result(KJob*)), SLOT(onCapabilitiesTestDone(KJob*)) );
       capJob->start();
     }
   } else {
-    //kWarning() << "Error during login:" << job->errorString();
-    if ( m_initialConnectDone ) {
-      cancelSessionCreation( login->session(),
-                             LoginFailError,
-                             i18n( "Could not connect to the IMAP-server %1.\n%2",
-                                   m_account->server(),
-                                   job->errorString() ) );
+    if ( job->error() == KIMAP::LoginJob::ERR_COULD_NOT_CONNECT ) {
+      if ( m_account ) {
+        cancelSessionCreation( login->session(),
+                               CouldNotConnectError,
+                               i18n( "Could not connect to the IMAP-server %1.\n%2",
+                                     m_account->server(), job->errorString() ) );
+      } else {
+        // Can happen when we loose all ready connections while trying to login.
+        cancelSessionCreation( login->session(),
+                               CouldNotConnectError,
+                               i18n( "Could not connect to the IMAP-server %1.\n%2",
+                                     "", job->errorString() ) );
+      }
     } else {
+      // Connection worked, but login failed -> ask for a different password or ssl settings.
       m_pendingInitialSession = login->session();
-      m_passwordRequester->requestPassword( PasswordRequesterInterface::WrongPasswordRequest, job->errorString() );
+      m_passwordRequester->requestPassword( PasswordRequesterInterface::WrongPasswordRequest,
+                                            job->errorString() );
     }
   }
 }
@@ -378,14 +379,19 @@ void SessionPool::onCapabilitiesTestDone( KJob *job )
   KIMAP::CapabilitiesJob *capJob = qobject_cast<KIMAP::CapabilitiesJob*>( job );
 
   if ( job->error() ) {
-    QString server;
     if ( m_account ) {
-      server = m_account->server();
+      cancelSessionCreation( capJob->session(),
+                             CapabilitiesTestError,
+                             i18n( "Could not test the capabilities supported by the "
+                                   "IMAP server %1.\n%2",
+                                   m_account->server(), job->errorString() ) );
+    } else {
+      // Can happen when we loose all ready connections while trying to check capabilities.
+      cancelSessionCreation( capJob->session(),
+                             CapabilitiesTestError,
+                             i18n( "Could not test the capabilities supported by the "
+                                   "IMAP server.\n%1", job->errorString() ) );
     }
-    cancelSessionCreation( capJob->session(),
-                           CapabilitiesTestError,
-                           i18n( "Could not test the capabilities supported by the IMAP server %1.",
-                                 server ) );
     return;
   }
 
@@ -394,7 +400,6 @@ void SessionPool::onCapabilitiesTestDone( KJob *job )
   expected << "IMAP4REV1";
 
   QStringList missing;
-
   foreach ( const QString &capability, expected ) {
     if ( !m_capabilities.contains( capability ) ) {
       missing << capability;
@@ -404,7 +409,8 @@ void SessionPool::onCapabilitiesTestDone( KJob *job )
   if ( !missing.isEmpty() ) {
     cancelSessionCreation( capJob->session(),
                            IncompatibleServerError,
-                           i18n( "Cannot use the IMAP server %1, some mandatory capabilities are missing: %2. "
+                           i18n( "Cannot use the IMAP server %1, "
+                                 "some mandatory capabilities are missing: %2. "
                                  "Please ask your sysadmin to upgrade the server.",
                                  m_account->server(),
                                  missing.join( ", " ) ) );
@@ -414,7 +420,7 @@ void SessionPool::onCapabilitiesTestDone( KJob *job )
   // If the extension is supported, grab the namespaces from the server
   if ( m_capabilities.contains( "NAMESPACE" ) ) {
     KIMAP::NamespaceJob *nsJob = new KIMAP::NamespaceJob( capJob->session() );
-    QObject::connect( nsJob, SIGNAL( result( KJob* ) ), SLOT( onNamespacesTestDone( KJob* ) ) );
+    QObject::connect( nsJob, SIGNAL(result(KJob*)), SLOT(onNamespacesTestDone(KJob*)) );
     nsJob->start();
     return;
   } else {
@@ -437,22 +443,29 @@ void SessionPool::onNamespacesTestDone( KJob *job )
     // ... otherwise we assume that we have to list explicitly each
     // namespace
 
-    m_namespaces = nsJob->personalNamespaces()
-                 + nsJob->userNamespaces()
-                 + nsJob->sharedNamespaces();
+    m_namespaces = nsJob->personalNamespaces() +
+                   nsJob->userNamespaces() +
+                   nsJob->sharedNamespaces();
   }
 
   declareSessionReady( nsJob->session() );
 }
 
+void SessionPool::onSessionStateChanged(KIMAP::Session::State newState, KIMAP::Session::State oldState)
+{
+  if (newState == KIMAP::Session::Disconnected && oldState != KIMAP::Session::Disconnected) {
+    onConnectionLost();
+  }
+}
+
 void SessionPool::onConnectionLost()
 {
   KIMAP::Session *session = static_cast<KIMAP::Session*>( sender() );
 
-  m_idlePool.removeAll( session );
+  m_unusedPool.removeAll( session );
   m_reservedPool.removeAll( session );
 
-  if ( m_idlePool.isEmpty() && m_reservedPool.isEmpty() ) {
+  if ( m_unusedPool.isEmpty() && m_reservedPool.isEmpty() ) {
     delete m_account;
     m_account = 0;
     m_namespaces.clear();
