@@ -1,7 +1,8 @@
 /* This file is part of the KDE project
+   Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
+   Copyright (c) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
    Copyright (C) 2009 Kevin Ottens <ervin@kde.org>
    Copyright (C) 2006-2008 Omat Holding B.V. <info@omat.nl>
-
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
@@ -22,7 +23,10 @@
 
 #include <klineedit.h>
 #include <kdialog.h>
+#include <akonadi/collection.h>
+#include <KJob>
 
+#include <QRegExpValidator>
 
 namespace Ui
 {
@@ -33,6 +37,13 @@ namespace MailTransport
 {
 class ServerTest;
 }
+namespace KPIMIdentities
+{
+class IdentityCombo;
+class IdentityManager;
+}
+
+class ImapResource;
 
 /**
  * @class SetupServer
@@ -46,9 +57,10 @@ class SetupServer : public KDialog
 public:
   /**
    * Constructor
+   * @param parentResource The resource this dialog belongs to
    * @param parent Parent WId
    */
-  SetupServer( WId parent );
+  SetupServer( ImapResource *parentResource, WId parent );
 
   /**
    * Destructor
@@ -62,22 +74,36 @@ private slots:
    * Call this if you want the settings saved from this page.
    */
   void applySettings();
-
+  void slotIdentityCheckboxChanged();
+  void slotMailCheckboxChanged();
+  void slotEncryptionRadioChanged();
+  void slotSubcriptionCheckboxChanged();
 private:
   void readSettings();
+  void populateDefaultAuthenticationOptions();
 
+  ImapResource *m_parentResource;
   Ui::SetupServerView *m_ui;
   MailTransport::ServerTest *m_serverTest;
   bool m_subscriptionsChanged;
   bool m_shouldClearCache;
+  QString m_vacationFileName;
+  KPIMIdentities::IdentityManager *m_identityManager;
+  KPIMIdentities::IdentityCombo *m_identityCombobox;
+  QString m_oldResourceName;
+  QRegExpValidator mValidator;
 
 private slots:
   void slotTest();
   void slotFinished( QList<int> testResult );
+
   void slotTestChanged();
   void slotComplete();
   void slotSafetyChanged();
   void slotManageSubscriptions();
+  void slotEnableWidgets();
+  void targetCollectionReceived( Akonadi::Collection::List collections );
+  void localFolderRequestJobFinished( KJob *job );
 };
 
 #endif
