@@ -187,7 +187,7 @@ private slots:
     QFETCH( int, errorCode );
     QFETCH( QStringList, capabilities );
 
-    QSignalSpy requesterSpy( requester, SIGNAL(done(int, QString)) );
+    QSignalSpy requesterSpy( requester, SIGNAL(done(int,QString)) );
 
     FakeServer server;
     server.setScenario( scenario );
@@ -197,7 +197,7 @@ private slots:
 
     QVERIFY( !pool.isConnected() );
 
-    QSignalSpy poolSpy( &pool, SIGNAL(connectDone(int, QString)) );
+    QSignalSpy poolSpy( &pool, SIGNAL(connectDone(int,QString)) );
 
     pool.setPasswordRequester( requester );
     QVERIFY( pool.connect( account ) );
@@ -253,13 +253,13 @@ private slots:
     ImapAccount *account = createDefaultAccount();
     DummyPasswordRequester *requester = createDefaultRequester();
 
-    QSignalSpy requesterSpy( requester, SIGNAL(done(int, QString)) );
+    QSignalSpy requesterSpy( requester, SIGNAL(done(int,QString)) );
 
     SessionPool pool( 2 );
     pool.setPasswordRequester( requester );
 
-    QSignalSpy connectSpy( &pool, SIGNAL(connectDone(int, QString)) );
-    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64, KIMAP::Session*, int, QString)) );
+    QSignalSpy connectSpy( &pool, SIGNAL(connectDone(int,QString)) );
+    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64,KIMAP::Session*,int,QString)) );
 
 
     // Before connect we can't get any session
@@ -369,8 +369,8 @@ private slots:
     SessionPool pool( 1 );
     pool.setPasswordRequester( requester );
 
-    QSignalSpy connectSpy( &pool, SIGNAL(connectDone(int, QString)) );
-    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64, KIMAP::Session*, int, QString)) );
+    QSignalSpy connectSpy( &pool, SIGNAL(connectDone(int,QString)) );
+    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64,KIMAP::Session*,int,QString)) );
     QSignalSpy lostSpy( &pool, SIGNAL(connectionLost(KIMAP::Session*)) );
 
 
@@ -494,7 +494,7 @@ private slots:
     SessionPool pool( 2 );
     pool.setPasswordRequester( requester );
 
-    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64, KIMAP::Session*, int, QString)) );
+    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64,KIMAP::Session*,int,QString)) );
 
     // Initial connect should trigger only a password request and a connect
     QVERIFY( pool.connect( account ) );
@@ -559,7 +559,7 @@ private slots:
     // This requester will delay the second reply by a second
     DummyPasswordRequester *requester = createDefaultRequester();
     requester->setDelays( QList<int>() << 20 << 1000 );
-    QSignalSpy requesterSpy( requester, SIGNAL(done(int, QString)) );
+    QSignalSpy requesterSpy( requester, SIGNAL(done(int,QString)) );
 
     FakeServer server;
 
@@ -582,8 +582,8 @@ private slots:
 
     QVERIFY( !pool.isConnected() );
 
-    QSignalSpy poolSpy( &pool, SIGNAL(connectDone(int, QString)) );
-    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64, KIMAP::Session*, int, QString)) );
+    QSignalSpy poolSpy( &pool, SIGNAL(connectDone(int,QString)) );
+    QSignalSpy sessionSpy( &pool, SIGNAL(sessionRequestDone(qint64,KIMAP::Session*,int,QString)) );
     QSignalSpy lostSpy( &pool, SIGNAL(connectionLost(KIMAP::Session*)) );
 
     pool.setPasswordRequester( requester );
@@ -639,6 +639,35 @@ private slots:
 
     server.quit();
   }
+
+  void shouldNotifyFailureToConnect()
+  {
+    // This tests what happens when we can't connect to the server, e.g. due to being offline.
+    // In this test we just use 0.0.0.0 as an invalid server IP, instead.
+    ImapAccount *account = createDefaultAccount();
+    account->setServer("0.0.0.0"); // so that the connexion fails
+    DummyPasswordRequester *requester = createDefaultRequester();
+    QList<DummyPasswordRequester::RequestType> requests;
+    QList<DummyPasswordRequester::ResultType> results;
+    // I don't want to see "WrongPasswordRequest". A password popup is annoying when we're offline or the server is down.
+    requests << DummyPasswordRequester::StandardRequest;
+    results << DummyPasswordRequester::PasswordRetrieved;
+    requester->setScenario( requests, results );
+
+    QSignalSpy requesterSpy( requester, SIGNAL(done(int,QString)) );
+    SessionPool pool( 2 );
+    QSignalSpy connectDoneSpy( &pool, SIGNAL(connectDone(int,QString)) );
+    QSignalSpy lostSpy( &pool, SIGNAL(connectionLost(KIMAP::Session*)) );
+    QVERIFY( !pool.isConnected() );
+    pool.setPasswordRequester( requester );
+    pool.connect( account );
+    QVERIFY( !pool.isConnected() );
+    QTRY_COMPARE( requesterSpy.count(), requests.count() );
+    QTRY_COMPARE( connectDoneSpy.count(), 1 );
+    QCOMPARE( connectDoneSpy.at(0).at(0).toInt(), (int)SessionPool::CouldNotConnectError );
+    QCOMPARE( lostSpy.count(), 0 ); // don't want this, it makes the resource reconnect immediately (and fail, and reconnect, and so on...)
+  }
+
 };
 
 QTEST_KDEMAIN_CORE( TestSessionPool )
