@@ -25,12 +25,14 @@
 #include "collectionannotationsattribute.h"
 #include "addressbookhandler.h"
 #include "collectiontreebuilder.h"
+#include "freebusyupdatehandler.h"
 
 #include <akonadi/attributefactory.h>
 #include <akonadi/cachepolicy.h>
 #include <akonadi/collectioncreatejob.h>
 #include <akonadi/collectiondeletejob.h>
 #include <akonadi/collectionfetchjob.h>
+#include <akonadi/collectionfetchscope.h>
 #include <akonadi/itemcreatejob.h>
 #include <akonadi/itemdeletejob.h>
 #include <akonadi/itemfetchjob.h>
@@ -81,6 +83,27 @@ static inline T imapToKolab( const T &imapObject )
   return kolabObject;
 }
 
+static QString mailBoxForImapCollection( const Akonadi::Collection &imapCollection, bool showWarnings )
+{
+  if ( imapCollection.remoteId().isEmpty() ) {
+    if ( showWarnings )
+      kWarning() << "Got incomplete ancestor chain:" << imapCollection;
+    return QString();
+  }
+
+  if ( imapCollection.parentCollection() == Akonadi::Collection::root() ) {
+    return QString( "" );
+  }
+
+  const QString parentMailbox = mailBoxForImapCollection( imapCollection.parentCollection(), showWarnings );
+  if ( parentMailbox.isNull() ) // invalid, != isEmpty() here!
+    return QString();
+
+  const QString mailbox =  parentMailbox + imapCollection.remoteId();
+
+  return mailbox;
+}
+
 KolabProxyResource::KolabProxyResource( const QString &id )
   : ResourceBase( id )
 {
@@ -95,19 +118,30 @@ KolabProxyResource::KolabProxyResource( const QString &id )
 
   m_monitor = new Monitor( this );
   m_monitor->itemFetchScope().fetchFullPayload();
+  m_monitor->itemFetchScope().setAncestorRetrieval( Akonadi::ItemFetchScope::All );
 
   m_collectionMonitor = new Monitor( this );
   m_collectionMonitor->fetchCollection( true );
   m_collectionMonitor->setCollectionMonitored(Collection::root());
   m_collectionMonitor->ignoreSession( Session::defaultSession() );
+  m_collectionMonitor->collectionFetchScope().setAncestorRetrieval( Akonadi::CollectionFetchScope::All );
 
-  connect(m_monitor, SIGNAL(itemAdded(const Akonadi::Item & , const Akonadi::Collection &)), this, SLOT(imapItemAdded(const Akonadi::Item & , const Akonadi::Collection &)));
-  connect(m_monitor, SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)), this, SLOT(imapItemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)));
-  connect(m_monitor, SIGNAL(itemRemoved(const Akonadi::Item &)), this, SLOT(imapItemRemoved(const Akonadi::Item &)));
-  connect(m_collectionMonitor, SIGNAL(collectionAdded(const Akonadi::Collection &, const Akonadi::Collection &)), this, SLOT(imapCollectionAdded(const Akonadi::Collection &, const Akonadi::Collection &)));
-  connect(m_collectionMonitor, SIGNAL(collectionRemoved(const Akonadi::Collection &)), this, SLOT(imapCollectionRemoved(const Akonadi::Collection &)));
-  connect(m_collectionMonitor, SIGNAL(collectionChanged(const Akonadi::Collection &)), this, SLOT(imapCollectionChanged(const Akonadi::Collection &)));
-  connect(m_collectionMonitor, SIGNAL(collectionMoved(Akonadi::Collection,Akonadi::Collection,Akonadi::Collection)), this, SLOT(imapCollectionMoved(Akonadi::Collection,Akonadi::Collection,Akonadi::Collection)) );
+  m_freeBusyUpdateHandler = new FreeBusyUpdateHandler( this );
+
+  connect( m_monitor, SIGNAL(itemAdded(Akonadi::Item,Akonadi::Collection)),
+           this, SLOT(imapItemAdded(Akonadi::Item,Akonadi::Collection)) );
+  connect( m_monitor, SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)),
+           this, SLOT(imapItemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)) );
+  connect( m_monitor, SIGNAL(itemRemoved(Akonadi::Item)), this, SLOT(imapItemRemoved(Akonadi::Item)) );
+
+  connect( m_collectionMonitor, SIGNAL(collectionAdded(Akonadi::Collection,Akonadi::Collection)),
+           this, SLOT(imapCollectionAdded(Akonadi::Collection,Akonadi::Collection)) );
+  connect( m_collectionMonitor, SIGNAL(collectionRemoved(Akonadi::Collection)),
+           this, SLOT(imapCollectionRemoved(Akonadi::Collection)) );
+  connect( m_collectionMonitor, SIGNAL(collectionChanged(Akonadi::Collection)),
+           this, SLOT(imapCollectionChanged(Akonadi::Collection)) );
+  connect( m_collectionMonitor, SIGNAL(collectionMoved(Akonadi::Collection,Akonadi::Collection,Akonadi::Collection)),
+           this, SLOT(imapCollectionMoved(Akonadi::Collection,Akonadi::Collection,Akonadi::Collection)) );
 
   setName( i18n("Kolab") );
 
@@ -123,7 +157,7 @@ void KolabProxyResource::retrieveCollections()
 {
   kDebug() << "RETRIEVECOLLECTIONS ";
   CollectionTreeBuilder *job = new CollectionTreeBuilder( this );
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(retrieveCollectionsTreeDone(KJob *)));
+  connect(job, SIGNAL(result(KJob*)), this, SLOT(retrieveCollectionsTreeDone(KJob*)));
 }
 
 void KolabProxyResource::retrieveCollectionsTreeDone(KJob* job)
@@ -150,7 +184,7 @@ void KolabProxyResource::retrieveItems( const Collection &collection )
   job->fetchScope().fetchFullPayload();
   job->setProperty( "resultCanBeEmpty", true );
 
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(retrieveItemFetchDone(KJob *)));
+  connect(job, SIGNAL(result(KJob*)), this, SLOT(retrieveItemFetchDone(KJob*)));
 }
 
 bool KolabProxyResource::retrieveItem( const Item &item, const QSet<QByteArray> &parts )
@@ -160,7 +194,7 @@ bool KolabProxyResource::retrieveItem( const Item &item, const QSet<QByteArray>
   m_retrieveState = RetrieveItem;
   ItemFetchJob *job = new ItemFetchJob( kolabToImap( item ) );
   job->fetchScope().fetchFullPayload();
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(retrieveItemFetchDone(KJob *)));
+  connect(job, SIGNAL(result(KJob*)), this, SLOT(retrieveItemFetchDone(KJob*)));
   return true;
 }
 
@@ -221,12 +255,8 @@ void KolabProxyResource::configure( WId windowId )
   // of focus stealing prevention technique
 
   QPointer<SetupKolab> kolabConfigDialog( new SetupKolab( this, windowId ) );
-  if ( kolabConfigDialog->exec() == QDialog::Accepted ) {
-    emit configurationDialogAccepted();
-  }
-  else {
-    emit configurationDialogRejected();
-  }
+  kolabConfigDialog->exec();
+  emit configurationDialogAccepted();
 
   delete kolabConfigDialog;
 }
@@ -462,6 +492,57 @@ void KolabProxyResource::applyAttributesFromImap( Collection &kolabCollection, c
   }
 }
 
+void KolabProxyResource::updateFreeBusyInformation( const Akonadi::Collection &imapCollection )
+{
+  const CollectionAnnotationsAttribute *annotationsAttribute = imapCollection.attribute<CollectionAnnotationsAttribute>();
+  if ( annotationsAttribute ) {
+    const QMap<QByteArray, QByteArray> annotations = annotationsAttribute->annotations();
+    const QByteArray folderType = annotations[ "/vendor/kolab/folder-type" ];
+    if ( folderType != "event" && folderType != "event.default" ) {
+      return; // no kolab calendar collection
+    }
+  } else {
+    return; // no kolab collection
+  }
+
+  const QString path = mailBoxForImapCollection( imapCollection, true );
+  if ( path.isEmpty() ) {
+    return;
+  }
+
+  const QString resourceId = imapCollection.resource();
+
+  QDBusInterface settingsInterface( QString::fromLatin1( "org.freedesktop.Akonadi.Agent.%1" ).arg( resourceId ),
+                                    QLatin1String( "/Settings" ), QLatin1String( "org.kde.Akonadi.Imap.Settings" ) );
+
+  QDBusInterface walletInterface( QString::fromLatin1( "org.freedesktop.Akonadi.Agent.%1" ).arg( resourceId ),
+                                  QLatin1String( "/Settings" ), QLatin1String( "org.kde.Akonadi.Imap.Wallet" ) );
+
+  if ( !settingsInterface.isValid() || !walletInterface.isValid() ) {
+    kWarning() << "unable to retrieve imap resource settings interface";
+    return;
+  }
+
+  const QDBusReply<QString> userNameReply = settingsInterface.call( QLatin1String( "userName" ) );
+  if ( !userNameReply.isValid() ) {
+    kWarning() << "unable to retrieve user name from imap resource settings";
+    return;
+  }
+
+  const QDBusReply<QString> passwordReply = walletInterface.call( QLatin1String( "password" ) );
+  if ( !passwordReply.isValid() ) {
+    kWarning() << "unable to retrieve password from imap resource settings";
+    return;
+  }
+
+  const QDBusReply<QString> hostReply = settingsInterface.call( QLatin1String( "imapServer" ) );
+  if ( !hostReply.isValid() ) {
+    kWarning() << "unable to retrieve host from imap resource settings";
+    return;
+  }
+
+  m_freeBusyUpdateHandler->updateFolder( path, userNameReply.value(), passwordReply.value(), hostReply.value() );
+}
 
 void KolabProxyResource::collectionChanged(const Akonadi::Collection& collection)
 {
@@ -511,7 +592,7 @@ void KolabProxyResource::addImapItem(const Item& item, Akonadi::Entity::Id colle
 
 void KolabProxyResource::imapItemAdded(const Item& item, const Collection &collection)
 {
-  kDebug() << "imapItemAdded " << item.id() << collection.id() << Collection::root().id();
+  kDebug() << item.id() << collection.id() << Collection::root().id();
   if (m_excludeAppend.contains(item.id()))   {
     kDebug() << "item already present";
     m_excludeAppend.removeAll(item.id());
@@ -520,7 +601,7 @@ void KolabProxyResource::imapItemAdded(const Item& item, const Collection &colle
 //TODO: slow, would be nice if ItemCreateJob would work with a Collection having only the remoteId set
   const Collection kolabCol = imapToKolab( collection );
   CollectionFetchJob *job = new CollectionFetchJob( kolabCol, CollectionFetchJob::Base, this );
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(collectionFetchDone(KJob *)));
+  connect(job, SIGNAL(result(KJob*)), this, SLOT(collectionFetchDone(KJob*)));
   m_ids[job] = QString::number(collection.id());
   m_items[job] = item;
 }
@@ -548,7 +629,7 @@ void KolabProxyResource::collectionFetchDone(KJob *job)
     Item::List newItems = handler->translateItems(Item::List() << m_items[job]);
     if (!newItems.isEmpty()) {
       ItemCreateJob *cjob = new ItemCreateJob( newItems[0],  c );
-      connect(cjob, SIGNAL(result(KJob*)), this, SLOT(itemCreatedDone(KJob *)));
+      connect(cjob, SIGNAL(result(KJob*)), this, SLOT(itemCreatedDone(KJob*)));
     }
   }
   m_ids.remove(job);
@@ -634,6 +715,8 @@ void KolabProxyResource::imapCollectionChanged(const Collection &collection)
     CollectionModifyJob *job = new CollectionModifyJob( kolabCollection, this );
     connect( job, SIGNAL(result(KJob*)), SLOT(kolabFolderChangeResult(KJob*)) );
   }
+
+  updateFreeBusyInformation( collection );
 }
 
 void KolabProxyResource::imapCollectionMoved(const Akonadi::Collection& collection, const Akonadi::Collection& source, const Akonadi::Collection& destination)
@@ -666,6 +749,8 @@ void KolabProxyResource::imapCollectionRemoved(const Collection &imapCollection)
   KolabHandler *handler = m_monitoredCollections.value(imapCollection.id());
   delete handler;
   m_monitoredCollections.remove(imapCollection.id());
+
+  updateFreeBusyInformation( imapCollection );
 }
 
 Collection KolabProxyResource::createCollection(const Collection& imapCollection)
@@ -734,8 +819,8 @@ bool KolabProxyResource::registerHandlerForCollection(const Akonadi::Collection&
 
     KolabHandler *handler = KolabHandler::createHandler(annotations["/vendor/kolab/folder-type"], imapCollection );
     if ( handler ) {
-      connect(handler, SIGNAL(deleteItemFromImap(const Akonadi::Item&)), this, SLOT(deleteImapItem(const Akonadi::Item&)));
-      connect(handler, SIGNAL(addItemToImap(const Akonadi::Item&, Akonadi::Entity::Id)), this, SLOT(addImapItem(const Akonadi::Item&, Akonadi::Entity::Id)));
+      connect(handler, SIGNAL(deleteItemFromImap(Akonadi::Item)), this, SLOT(deleteImapItem(Akonadi::Item)));
+      connect(handler, SIGNAL(addItemToImap(Akonadi::Item,Akonadi::Entity::Id)), this, SLOT(addImapItem(Akonadi::Item,Akonadi::Entity::Id)));
       m_monitor->setCollectionMonitored(imapCollection);
       m_monitoredCollections.insert(imapCollection.id(), handler);
       return true;
