@@ -34,6 +34,7 @@
 #include <time.h>
 #include <unistd.h>
 
+
 static void initRandomSeed()
 {
   static bool init = false;
@@ -549,7 +550,7 @@ QString Maildir::addEntry( const QByteArray& data )
      * For reference: http://trolltech.com/developer/task-tracker/index_html?method=entry&id=211215
      */
     if (!f.rename( finalKey )) {
-        qWarning() << "Maildir: Failed to add entry: " << finalKey  << "!";
+        qWarning() << "Maildir: Failed to add entry: " << finalKey  << "! Error: " << f.errorString();
     }
     return uniqueKey;
 }
@@ -603,8 +604,35 @@ QString Maildir::changeEntryFlags(const QString& key, const Akonadi::Item::Flags
     finalKey.prepend( d->path + QString::fromLatin1("/cur/") );
     
     QFile f( realKey );
+    if (QFile::exists(finalKey)) {
+      QFile destFile(finalKey);
+      QByteArray destContent;
+      if (destFile.open(QIODevice::ReadOnly) ) {
+        destContent = destFile.readAll();
+        destFile.close();
+      }
+      QByteArray sourceContent;
+      if (f.open(QIODevice::ReadOnly) ) {
+        sourceContent = f.readAll();
+        f.close();
+      }
+      
+      if ( destContent != sourceContent ) {         
+         QString newFinalKey = "1-" + newUniqueKey;
+         int i = 1;
+         while ( QFile::exists(d->path + QString::fromLatin1("/cur/") + newFinalKey ) ) {
+           i++;
+           newFinalKey = QString::number(i) + "-" + newUniqueKey;
+         }
+         finalKey = d->path + QString::fromLatin1("/cur/") + newFinalKey;
+      } else {
+            QFile::remove( finalKey ); //they are the same                                                    
+      }
+    } 
+    
     if (!f.rename( finalKey )) {
-        qWarning() << "Maildir: Failed to add entry: " << finalKey  << "!";
+        qWarning() << "Maildir: Failed to add entry: " << finalKey  << "! Error: " << f.errorString();
+        newUniqueKey = "";
     }
     return newUniqueKey;
 }
@@ -679,7 +707,7 @@ QString Maildir::moveEntryTo( const QString &key, const Maildir &destination )
   // ### is this safe regarding the maildir locking scheme?
   const QString targetKey = destination.path() + QDir::separator() + QLatin1String( "new" ) + QDir::separator() + key;
   if ( !f.rename( targetKey ) ) {
-    kDebug() << "Failed to rename" << realKey << "to" << targetKey;
+    kDebug() << "Failed to rename" << realKey << "to" << targetKey << "! Error: " << f.errorString();;
     return QString();
   }
 
