@@ -102,6 +102,7 @@ MaildirResource::MaildirResource( const QString &id )
   changeRecorder()->itemFetchScope().setAncestorRetrieval( ItemFetchScope::All );
   changeRecorder()->itemFetchScope().setFetchModificationTime( false );
   changeRecorder()->collectionFetchScope().setAncestorRetrieval( CollectionFetchScope::All );
+  changeRecorder()->fetchChangedOnly( true );
 
   setHierarchicalRemoteIdentifiersEnabled( true );
 
@@ -263,6 +264,10 @@ void MaildirResource::itemChanged( const Akonadi::Item& item, const QSet<QByteAr
 
       if ( flagsChanged ) { //flags changed, store in file name and get back the new filename (id)
         const QString newKey = dir.changeEntryFlags( item.remoteId(), item.flags() );
+        if (newKey.isEmpty()) {
+          cancelTask( i18n("Failed to change the flags for the mail.") );
+          return;          
+        }
         newItem.setRemoteId( newKey );
       }
 
@@ -363,7 +368,7 @@ void MaildirResource::itemRemoved(const Akonadi::Item & item)
     m_fsWatcher->addDir( dirPath + QLatin1Literal("/new") );
     m_fsWatcher->addDir( dirPath + QLatin1Literal("/cur") );
   }
-  qDebug() << "Item removed";
+  kDebug() << "Item removed"<<item.id()<<" in collection :"<<item.parentCollection().id();
   changeProcessed();
 }
 
@@ -411,8 +416,12 @@ void MaildirResource::retrieveCollections()
   root.setParentCollection( Collection::root() );
   root.setRemoteId( mSettings->path() );
   root.setName( name() );
-  root.setRights( Collection::CanChangeItem | Collection::CanCreateItem | Collection::CanDeleteItem
-                | Collection::CanCreateCollection );
+  if ( mSettings->readOnly() ) {
+    root.setRights( Collection::ReadOnly );
+  } else {
+    root.setRights( Collection::CanChangeItem | Collection::CanCreateItem | Collection::CanDeleteItem
+                    | Collection::CanCreateCollection );
+  } 
 
   CachePolicy policy;
   policy.setInheritFromParent( false );
@@ -705,7 +714,7 @@ void MaildirResource::fsWatchFileFetchResult( KJob* job )
     item.setSize( entrySize );
 
   Item::Flags flags = md.readEntryFlags( entry );
-  Q_FOREACH( Item::Flag flag, flags ) {
+  Q_FOREACH( const Item::Flag& flag, flags ) {
     item.setFlag(flag);      
   }
     
